## 申万行业成分构成(分级)

接口：index_member_all

描述：按三级分类提取申万行业成分，可提供某个分类的所有成分，也可按股票代码提取所属分类，参数灵活

限量：单次最大2000行，总量不限制

权限：用户需2000积分可调取，积分获取方法请参阅积分获取办法 

输入参数

| 名称 | 类型 | 必选 | 描述 |
| --- | --- | --- | --- |
| l1_code | str | N | 一级行业代码 |
| l2_code | str | N | 二级行业代码 |
| l3_code | str | N | 三级行业代码 |
| ts_code | str | N | 股票代码 |
| is_new | str | N | 是否最新（默认为“Y是”） |

输出参数

| 名称 | 类型 | 默认显示 | 描述 |
| --- | --- | --- | --- |
| l1_code | str | Y | 一级行业代码 |
| l1_name | str | Y | 一级行业名称 |
| l2_code | str | Y | 二级行业代码 |
| l2_name | str | Y | 二级行业名称 |
| l3_code | str | Y | 三级行业代码 |
| l3_name | str | Y | 三级行业名称 |
| ts_code | str | Y | 成分股票代码 |
| name | str | Y | 成分股票名称 |
| in_date | str | Y | 纳入日期 |
| out_date | str | Y | 剔除日期 |
| is_new | str | Y | 是否最新Y是N否 |

接口示例

```python
#获取黄金分类的成份股
df = pro.index_member_all(l3_code='850531.SI')

#获取000001.SZ所属行业
df = pro.index_member_all(ts_code='000001.SZ')
```

数据示例

```python
l1_code l1_name     l2_code       l2_name  l3_code     l3_name    ts_code       name   in_date
0   801050.SI    有色金属  801053.SI     贵金属  850531.SI      黄金  000506.SZ      *ST中润  20220729
```